import { verifySession } from "@/app/_lib/dal";
import { getCollection} from "@/app/_lib/mongodb";
import { ObjectId } from "mongodb";
import { NextRequest } from "next/server";
import { getLinkList } from "@/app/_lib/data/link";

export async function GET(req: NextRequest) {
    try {
        // Check if the user is authenticated
        const session = await verifySession()
        if (!session) {
            // User is not authenticated
            return new Response(null, { status: 401 })
        }
        // 获取分页参数
        const page = parseInt(req.nextUrl.searchParams.get('page') || '1') || 1;
        const pageSize = parseInt(req.nextUrl.searchParams.get('pageSize') || '10') || 10;

        const res = await getLinkList({ page, pageSize })

        return Response.json(res)
    } catch  {
        return Response.error()
    }
}

export async function DELETE(req: NextRequest, { params }: { params: Promise<{ id: string }> }) {
    try {
        const session = await verifySession()

        // Check if the user is authenticated
        if (!session) {
            // User is not authenticated
            return new Response(null, { status: 401 })
        }
        // 获取路径参数
        const slug = (await params).id
        const collection = await getCollection('link-type')
        collection.deleteOne({
            _id: new ObjectId(slug)
        })
        return Response.json({ message: '删除成功' })
    } catch {
        return Response.error()
    }
}
